# New in 0.17.3 (2022-08-26)

## Changes

-   Pin sphinx_gallery to fix tutorial cards on docs [#1657]
-   Use latest tutorials in release [#1657]

## Contributors

-   [@watiss]
-   [@adamgayoso]

[#1657]: https://github.com/scverse/scvi-tools/pull/1657
[@watiss]: https://github.com/watiss
[@adamgayoso]: https://github.com/adamgayoso
